# Code to calculate and analyse macroinvertebrate community stoichiometry in
# Beck M., Billoir E., Usseglio-Polatera P., Meyer A., Gautreau E., Danger M. (2024)
# Effects of water nutrient concentrations on stream macroinvertebrate community stoichiometry: a large-scale study
# BIORXIV/2024/574823


# set working directory, import packages and data
# community, stoichio and environmental data is provided at: https://zenodo.org/records/10624783
# stoichiometry information is taken from Beck et al.(2022) A database of West European headwater macroinvertebrate stoichiometric traits. Global Ecology and Biogeography, 31, 4-9. https://doi.org/10.1111/geb.13413
setwd("")
library(tidyverse)
library(dplyr)
library(ggplot2)
library(EnvStats)
library(broom)
library(purrr)

commdata<-read.csv("data_comm.csv", header=TRUE, na.strings="NA", stringsAsFactors=FALSE)
stoichio_db <- read.csv("stoichio.csv", header=TRUE, na.strings="NA", stringsAsFactors=FALSE, check.names=FALSE)
env<-read.csv("data_env.csv", header=TRUE, na.strings="NA", stringsAsFactors=FALSE)

#___________________________________________
#calculate community stoichios at each site
#___________________________________________
#match stoichio info
commdata_t <- as.data.frame(t(commdata[,-1]))
colnames(commdata_t) <- commdata$cd_opecont
commdata_t$taxon <- rownames(commdata_t)

commdata_t<-left_join(commdata_t, stoichio_db, by="taxon")

#community ratios
#complete community
commdata_c<- commdata_t %>%
  filter(!is.na(mean_c)) %>% #to exclude taxa for which corresponding stoichio is not available
  mutate_at(vars(2:1308), funs(log1p(.))) %>%  #log(x+1) abundance data 
  mutate_at(vars(2:1308), funs(./sum(.))) %>% #relative frequency
  mutate_at(vars(2:1308), funs(.*mean_c)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_c")

commdata_n<- commdata_t %>%
  filter(!is.na(mean_n)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*mean_n)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_n")

commdata_p<- commdata_t %>%
  filter(!is.na(mean_p)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*mean_p)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_p")

commdata_cn<- commdata_t %>%
  filter(!is.na(mean_cn)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_cn))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_cn")

commdata_cp<- commdata_t %>%
  filter(!is.na(mean_cp)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_cp))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_cp")

commdata_np<- commdata_t %>%
  filter(!is.na(mean_np)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>% 
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_np))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_np")

commstoichios<- rbind(commdata_c, commdata_n, commdata_p, commdata_cn, commdata_cp, commdata_np)
commstoichios_t <- as.data.frame(t(commstoichios[,-ncol(commstoichios)])) #transpose dataframe
colnames(commstoichios_t) <- commstoichios$index
commstoichios_t$cd_opecont <- rownames(commstoichios_t)
write.csv(commstoichios, file="commstoichios_complete.csv", row.names=F)

#group-wise
# -> run this two times: grouping by 'class' and 'food_cat' (i.e. suppress one of the 'group_by()' statements)
commdata_c<- commdata_t %>%
  filter(!is.na(mean_c)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  group_by(class) %>% #'class' or 'food_cat'
  #group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*mean_c)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_c")

commdata_n<- commdata_t %>%
  filter(!is.na(mean_n)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  group_by(class) %>% #-> 'class' or 'food_cat'
  #group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*mean_n)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_n")

commdata_p<- commdata_t %>%
  filter(!is.na(mean_p)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  group_by(class) %>% #-> 'class' or 'food_cat'
 # group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*mean_p)) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_p")

commdata_cn<- commdata_t %>%
  filter(!is.na(mean_cn)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  group_by(class) %>% #-> 'class' or 'food_cat'
  #group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_cn))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_cn")

commdata_cp<- commdata_t %>%
  filter(!is.na(mean_cp)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>%
  group_by(class) %>% #-> 'class' or 'food_cat'
  #group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_cp))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_cp")

commdata_np<- commdata_t %>%
  filter(!is.na(mean_np)) %>%
  mutate_at(vars(2:1308), funs(log1p(.))) %>% 
  group_by(class) %>% #-> 'class' or 'food_cat'
  #group_by(food_cat) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  mutate_at(vars(2:1308), funs(.*log(mean_np))) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE) %>%
  mutate(index="comm_np")
commstoichios<- rbind(commdata_c, commdata_n, commdata_p, commdata_cn, commdata_cp, commdata_np)
commstoichios[commstoichios == 0] <- NA

#pick one of the two commands depending on the group you grouped by:
commstoichios_class <- commstoichios %>% select(class, index, everything()) %>% rename('community'= class) %>% filter(community %in% c('Gastropoda', 'Hirudinea', 'Insecta', 'Malacostraca'))
commstoichios_food <- commstoichios %>% select(food_cat, index, everything()) %>% rename('community'= food_cat)

#when you have run the calculation for both groupings:
commstoichios_group<- rbind(commstoichios_class, commstoichios_food)

#bring in long format (when bugging, try this with Excel/Calc, simply re-stack the data)
comm_c<- commstoichios_group %>% filter(index== 'comm_c') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))
comm_n<- commstoichios_group %>% filter(index== 'comm_n') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))
comm_p<- commstoichios_group %>% filter(index== 'comm_p') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))
comm_cn<- commstoichios_group %>% filter(index== 'comm_cn') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))
comm_cp<- commstoichios_group %>% filter(index== 'comm_cp') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))
comm_np<- commstoichios_group %>% filter(index== 'comm_np') %>% gather(key=cd_opecont, value=value, -community, -index) %>% rename('stoichio'='index') %>% mutate(cd_opecont = as.numeric(cd_opecont))

stoichios_long_group <- rbind(comm_c, comm_n, comm_p, comm_cn, comm_cp, comm_np)
write.csv(commstoichios, file="commstoichios_groupwise.csv", row.names=F)


#___________________________________________
#community stoichio along nutrient gradient
#___________________________________________
#match environmental variables
#complete community:
commstoichios_t<-merge(commstoichios_t, env, by="cd_opecont")
commstoichios_t$stat_N<-factor(commstoichios_t$stat_N, levels=c("good", "intermediate", "bad"))
levels(commstoichios_t$stat_N)<-c("good", "interm", "bad")

#gather into long format for easier plotting/analysis
stoichios_long<- commstoichios_t %>% gather(key=stoichio, value=value, comm_c:comm_np)
stoichios_long$stoichio<-factor(stoichios_long$stoichio, levels=c("comm_c", "comm_n", "comm_p", "comm_cn", "comm_cp", "comm_np"))


#group-wise community stoichios:
stoichios_long_group <- left_join(stoichios_long_group, env, by="cd_opecont")
stoichios_long_group$stat_N<-factor(stoichios_long_group$stat_N, levels=c("good", "intermediate", "bad"))
levels(stoichios_long_group$stat_N)<-c("good", "interm", "bad")

#____________
#statistics
#___________
#check significance of interaction term (waterP*stat_N)
# individual stoichios
m1<- lm(value ~ log(waterP)*stat_N, data=subset(stoichios_long, stoichio=="comm_c")) #within group option, e.g.: class=="Gastropoda" & stoichio=="comm_c"
m2<- lm(value ~ log(waterP)+stat_N, data=subset(stoichios_long, stoichio=="comm_c"))       
anova(m1, m2)
# if p<0.5: the model with interaction is significantly better
# if p>0.5: the more simple model (without interaction term) is preferred

#to check details of a model:
summary(m2)

#calculate all stoichios at once
#complete community
lm_complete<- stoichios_long %>%
  filter(!is.na(value)) %>%
  nest(-stoichio) %>%
  mutate(fit = map(data, ~ lm(value ~ log(waterP)*stat_N, data = .)), #->change here for interaction vs. no-interaction term
         results = map(fit, tidy), #tidy or glance
         results2 = map(fit, glance)) %>% 
  unnest(results, results2) %>%
  select(stoichio, term:p.value) %>%
  mutate(model_sig = (case_when(p.value < 0.001 ~ "***",
                                p.value < 0.01 ~ "**",
                                p.value < 0.05 ~ "*",
                                p.value < 0.1 ~ ".")),
         community = "complete")

write.csv(lm_complete, file="lm_waterPXstatN_complete.csv",row.names=FALSE)


#group-wise
lm_group<- stoichios_long_group %>%
  filter(!is.na(value)) %>%
  nest(-community, -stoichio) %>%
  mutate(fit = map(data, ~ lm(value ~ log(waterP)*stat_N, data = .)), #->change here for interaction vs. no-interaction term
         results = map(fit, tidy), #tidy or glance
         results2 = map(fit, glance)) %>% 
  unnest(results, results2) %>%
  select(community, stoichio, term:p.value) %>%
  mutate(model_sig = (case_when(p.value < 0.001 ~ "***",
                                p.value < 0.01 ~ "**",
                                p.value < 0.05 ~ "*",
                                p.value < 0.1 ~ ".")))

write.csv(lm_group, file="lm_waterPXstatN_groupwise.csv",row.names=FALSE)

#______
#plot
#______
#change labels (optionally, you may have to change it back if running stats afterwards)
commstoichios_t<- commstoichios_t %>% rename('Level N' = stat_N)
levels(stoichios_long$stoichio)<-c("%C", "%N", "%P", "C:N", "C:P", "N:P")

#complete community
jpeg(paste("commstoichio_waterPXstatN", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=stoichios_long,
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_smooth(method="lm", se=FALSE, size=1, aes(group=`Level N`, color=`Level N`)) +
  facet_wrap(~stoichio, nrow=2, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="%/ratio", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()


#group-wise
stoichios_long_group<- stoichios_long_group %>% rename('Level N' = stat_N)
levels(stoichios_long_group$stoichio)<-c("%C", "%N", "%P", "C:N", "C:P", "N:P")

#the code to plot community %P, C:P and N:P is provided, for the other community stoichio variables: 
#adapt the filename, the sub-setting command, as well as the y-axis label

# run the plotting function below seperately for tax. and feeding groups:
toplot<- stoichios_long_group %>% filter(community %in% c("Gastropoda", "Hirudinea", "Insecta", "Malacostraca"))
toplot<- stoichios_long_group %>% filter(community %in% c("detritivore", "herbivore", "omni", "predator"))

jpeg(paste("commstoichio_waterPXstatN_commP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_p')),
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_smooth(method="lm", se=FALSE, size=1, aes(group=`Level N`, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="%P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()

jpeg(paste("commstoichio_waterPXstatN_commCP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_cp')),
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_smooth(method="lm", se=FALSE, size=1, aes(group=`Level N`, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="C:P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()

jpeg(paste("commstoichio_waterPXstatN_commNP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_np')),
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_smooth(method="lm", se=FALSE, size=1, aes(group=`Level N`, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="N:P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()


#plot without interaction term
#(in this study only relevant for group-wise stoichios)
#predict commstoichio based on models without interaction for plotting
# (difference in code for 'hirudinea' and 'herbivore' because for some stoichio variables trait infos is available for larger number of taxa)

stoichios_long_group<- stoichios_long_group %>% rename('Level N' = stat_N) #might be necessary if variable name was change for plotting

gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_c'))
gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_n'))
gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_p'))
gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_cn'))
gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_cp'))
gas<-subset(stoichios_long_group, community=='Gastropoda' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(gas, stoichio=='comm_np'))
total_gas<-cbind(gas, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_c'))
hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_n'))
hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_p'))
hir_p<- cbind(hir, pred_p=predict(lm_p))
hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_cn'))
hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_cp'))
hir<-subset(stoichios_long_group, community=='Hirudinea' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(hir, stoichio=='comm_np'))
total_hir<-cbind(hir, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))
total_hir<- left_join(hir_p, total_hir[, c('cd_opecont','pred_c','pred_n', 'pred_cn', 'pred_cp', 'pred_np')], by=c('cd_opecont' = 'cd_opecont'))
total_hir<- total_hir %>% select("community", "stoichio", "cd_opecont", "value", "waterN", "waterP", "stat_N", "stat_P", "date", "pred_c", "pred_n", "pred_p", "pred_cn", "pred_cp", "pred_np")

ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_c'))
ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_n'))
ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_p'))
ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_cn'))
ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_cp'))
ins<-subset(stoichios_long_group, community=='Insecta' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(ins, stoichio=='comm_np'))
total_ins<-cbind(ins, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_c'))
crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_n'))
crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_p'))
crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_cn'))
crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_cp'))
crust<-subset(stoichios_long_group, community=='Malacostraca' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(crust, stoichio=='comm_np'))
total_crust<-cbind(crust, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_c'))
detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_n'))
detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_p'))
detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_cn'))
detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_cp'))
detri<-subset(stoichios_long_group, community=='detritivore' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(detri, stoichio=='comm_np'))
total_detri<-cbind(detri, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_c'))
herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_n'))
herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_p'))
herbi_p<- cbind(herbi, pred_p=predict(lm_p))
herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_cn'))
total_herbi1<-cbind(herbi, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_cn=predict(lm_cn))
herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_cp'))
herbi_cp<- cbind(herbi, pred_cp=predict(lm_cp))
herbi<-subset(stoichios_long_group, community=='herbivore' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(herbi, stoichio=='comm_np'))
herbi_np<- cbind(herbi, pred_cp=predict(lm_np))
total_herbi2<-cbind(herbi, pred_cp=predict(lm_cp), pred_np=predict(lm_np))
total_herbi<- left_join(herbi_p, total_herbi2[, c('cd_opecont','pred_cp','pred_np')], by=c('cd_opecont' = 'cd_opecont'))
total_herbi<- left_join(total_herbi, total_herbi1[, c('cd_opecont','pred_c','pred_n', 'pred_cn')], by=c('cd_opecont' = 'cd_opecont'))
total_herbi<- total_herbi %>% select("community", "stoichio", "cd_opecont", "value", "waterN", "waterP", "stat_N", "stat_P", "date", "pred_c", "pred_n", "pred_p", "pred_cn", "pred_cp", "pred_np")

omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_c'))
omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_n'))
omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_p'))
omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_cn'))
omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_cp'))
omni<-subset(stoichios_long_group, community=='omni' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(omni, stoichio=='comm_np'))
total_omni<-cbind(omni, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_c' & !is.na(value))
lm_c<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_c'))
pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_n' & !is.na(value))
lm_n<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_n'))
pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_p' & !is.na(value))
lm_p<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_p'))
pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_cn' & !is.na(value))
lm_cn<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_cn'))
pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_cp' & !is.na(value))
lm_cp<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_cp'))
pred<-subset(stoichios_long_group, community=='predator' & stoichio=='comm_np' & !is.na(value))
lm_np<- lm(value~log(waterP)+stat_N, data=subset(pred, stoichio=='comm_np'))
total_pred<-cbind(pred, pred_c=predict(lm_c), pred_n=predict(lm_n), pred_p=predict(lm_p), pred_cn=predict(lm_cn), pred_cp=predict(lm_cp), pred_np=predict(lm_np))

#run this for each group (adapting the 'subset') and then merge it to total df
commstoichios_pred<-rbind(total_gas, total_hir, total_ins, total_crust, total_detri, total_herbi, total_omni, total_pred)
write.csv(commstoichios_pred, file = "commstoichios_classweighted_pred.csv", row.names=FALSE)

commstoichios_group<- stoichios_long_group %>% pivot_wider(names_from=stoichio, values_from=value)
commstoichios_group<- left_join(commstoichios_group, commstoichios_pred[,c('community', 'cd_opecont', 'pred_c', 'pred_n', 'pred_p', 'pred_cn', 'pred_cp', 'pred_np')], by=c('cd_opecont'='cd_opecont', 'community'='community'))
stoichios_long_group<- commstoichios_group %>% gather(key=stoichio, value=value, comm_c:comm_np)
stoichios_long_group2<- commstoichios_group %>% gather(key=stoichio, value=value_pred, pred_c:pred_np)
stoichios_long_group<-cbind(stoichios_long_group, stoichios_long_group2[ncol(stoichios_long_group2)])

stoichios_long$stoichio<-factor(stoichios_long$stoichio, levels=c("comm_c", "comm_n", "comm_p", "comm_cn", "comm_cp", "comm_np"))
stoichios_long_group<- stoichios_long_group %>% rename('Level N' = stat_N)
levels(stoichios_long_group$stoichio)<-c("%C", "%N", "%P", "C:N", "C:P", "N:P")

#the code to plot community %P, C:P and N:P is provided, for the other community stoichio variables: 
#adapt the filename, the sub-setting command, as well as the y-axis label

# run the plotting function below seperately for tax. and feeding groups:
toplot<- stoichios_long_group %>% filter(community %in% c("Gastropoda", "Hirudinea", "Insecta", "Malacostraca"))
toplot<- stoichios_long_group %>% filter(community %in% c("detritivore", "herbivore", "omni", "predator"))

jpeg(paste("commstoichio_waterP0statN_commP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_p')), 
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_line(method="lm", se=FALSE, stat="smooth", size=1, aes(x=log(waterP), y=value_pred, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="%P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()

jpeg(paste("commstoichio_waterP0statN_commCP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_cp')), 
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_line(method="lm", se=FALSE, stat="smooth", size=1, aes(x=log(waterP), y=value_pred, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="C:P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()

jpeg(paste("commstoichio_waterP0statN_commNP", ".jpg", sep=""), width=2800, height=900, res=300)
ggplot(
  data=subset(toplot, stoichio %in% c('comm_np')), 
  aes(x=log(waterP), y=value, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_line(method="lm", se=FALSE, stat="smooth", size=1, aes(x=log(waterP), y=value_pred, color=`Level N`)) +
  facet_wrap(~community, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Community stoichiometry") +
  scale_y_continuous(name="N:P", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()

#__________________________________
#proportion of tax/feeding groups
#__________________________________
prop_classes<- commdata_t %>%
  filter(!is.na(mean_c)) %>% #to exclude taxa for stoichio is not available
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  group_by(class) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE)  %>%
  mutate_at(vars(2:1308), round, 4)%>%
  rename('community' = class)

prop_food<- commdata_t %>%
  filter(!is.na(mean_c)) %>%
  mutate_at(vars(2:1308), funs(./sum(.))) %>%
  group_by(food_cat) %>%
  summarise_at(vars(2:1308), sum, na.rm=TRUE)  %>%
  mutate_at(vars(2:1308), round, 4) %>%
  rename('community' = food_cat)

write.csv(prop_classes, file = "propclasses_tax.csv")

prop_groups<- rbind(prop_classes, prop_food)
prop_groups_t <- as.data.frame(t(prop_groups[,-1])) #transpose dataframe
colnames(prop_groups_t) <- prop_groups$community
prop_groups_t$cd_opecont <- rownames(prop_groups_t)

prop_groups_t<-merge(prop_groups_t, env, by="cd_opecont")
prop_groups_t$stat_N<-factor(prop_groups_t$stat_N, levels=c("good", "intermediate", "bad"))
levels(prop_groups_t$stat_N)<-c("good", "interm", "bad")

#gather into long format for easier plotting/analysis
props_long<- prop_groups_t %>% gather(key=group, value=value, Arachnida:predator)
props_long$group<-factor(props_long$group, levels=c("Arachnida", "Bivalvia", "Gastropoda", "Hirudinea", "Insecta", "Malacostraca", "Oligochaeta", "Turbellaria", "detritivore", "herbivore", "omni", "predator"))

#____________
#statistics
#___________
lm_props<- props_long %>%
  filter(!is.na(value)) %>%
  nest(-group) %>%
  mutate(fit = map(data, ~ lm(value ~ log(waterP)*stat_N, data = .)), #->change here for interaction vs. no-interaction term
         results = map(fit, tidy),
         results2 = map(fit, glance)) %>% 
  unnest(results, results2) %>%
  select(group, term:p.value) %>%
  mutate(model_sig = (case_when(p.value < 0.001 ~ "***",
                                p.value < 0.01 ~ "**",
                                p.value < 0.05 ~ "*",
                                p.value < 0.1 ~ ".")))

#______
#plot
#______
props_long<- props_long %>% rename('Level N' = stat_N)
jpeg(paste("propclasses_waterPXstatN", ".jpg", sep=""), width=2800, height=900, res=300)

ggplot(
  data=subset(props_long, group %in% c('Bivalvia', 'Gastropoda', 'Hirudinea', 'Insecta', 'Malacostraca', 'Oligochaeta', 'Turbellaria')), #pick either the tax or feeding group subset
  #data=subset(props_long, group %in% c('detritivore', 'herbivore', 'omni', 'predator')), #pick either the tax or feeding group subset
  aes(x=log(waterP), y=value*100, col=`Level N`), alpha=0.8) +
  geom_point(pch=16, alpha=0.30) +
  geom_smooth(method="lm", se=FALSE, size=1, aes(group=`Level N`, color=`Level N`)) +
  facet_wrap(~group, nrow=1, scales="free_y") +
  scale_color_manual(values=c("limegreen", "gold", "indianred")) +
  theme_bw() +
  theme(
    legend.position="top",
    panel.grid.major.x=element_blank()) +
  labs(title="Group proportions") +
  scale_y_continuous(name="%", limits=c(NA, NA)) +
  scale_x_continuous(name="log(water P)", limits=c(NA, NA))
dev.off()